local fs = require "nixio.fs" 

m = Map("ftp-uploader", translate("FTP Uploader"))

section_global = m:section(TypedSection, "global", translate("Enable/ Disable"))
section_global.anonymous = false
section_global.addremove = false
section_global.name = "global"

option_enabled = section_global:option(Flag, "enabled", translate("Enabled"),
	translate("Enable Modbus to FTP"))
option_enabled.rmempty=false
option_enabled.default="1"

s = m:section(TypedSection, "ftp_uploader", translate("FTP Configuration"))
s.anonymous = true
s.addremove = false


local_file_path = s:option(Value, "local_file_path", translate("Local File Path"),
        translate("Path to store files locally before they are uploaded to server"))
local_file_path.default = "/root/ftp-files/"

protocol = s:option(ListValue, "protocol", translate("Protocol"),
        translate("Protocol that is being used."))
protocol:value("ftp", translate("FTP"))
protocol:value("sftp", translate("SFTP"))
protocol:value("scp", translate("SCP"))
protocol.default = "ftp"

--host
host = s:option(Value, "host", translate("Host IP Address"), translate("IP address or host name of the server to upload the data files"))
host.datatype = "host"

--port
port = s:option(Value, "port", translate("Port"), translate("Default port number for FTP is 21, SCP is 22"))
port.datatype = "port"
port.default = "21"

--remote path
remote_path = s:option(Value, "remote_path", translate("Remote Path"), translate("Folder path on the remote server to upload the files(e.g ftp_files/)"))
remote_path.datatype = "string"

username = s:option(Value, "username", translate("Username"))
username.datatype = "maxlength(512)"

pass = s:option(Value, "pass", translate("Password"))
pass.password = true

--upload_interval
upload_interval = s:option(Value, "upload_interval", translate("Upload Interval (Seconds)"))
upload_interval.datatype = "range(1,86400)"
upload_interval.default = "60"

return m
